@@ -6,12 +6,10 @@ use rattler_conda_types::Platform;
 use tempfile::TempDir;
 
 use crate::{
-    common::{
-        LockFileExt, PixiControl,
-        package_database::{Package, PackageDatabase},
-    },
+    common::{LockFileExt, PixiControl},
     setup_tracing,
 };
+use pixi_test_utils::{MockRepoData, Package};
 
 /// Test that verifies build backend receives the correct resolved source path
 /// when a relative path is specified in the source field
@@ -20,7 +18,7 @@ async fn test_build_with_relative_source_path() {
     setup_tracing();
 
     // Create a simple package database for our test
-    let mut package_database = PackageDatabase::default();
+    let mut package_database = MockRepoData::default();
     package_database.add_package(Package::build("empty-backend", "0.1.0").finish());
 
     // Write the repodata to disk
@@ -137,7 +135,7 @@ preview = ["pixi-build"]
 async fn test_build_with_absolute_source_path() {
     setup_tracing();
 
-    let mut package_database = PackageDatabase::default();
+    let mut package_database = MockRepoData::default();
     package_database.add_package(Package::build("empty-backend", "0.1.0").finish());
 
     let channel_dir = TempDir::new().unwrap();
@@ -194,19 +192,19 @@ preview = ["pixi-build"]
 
     let workspace = dbg!(pixi.workspace()).unwrap();
 
-    if let Some(package) = &workspace.package {
-        if let Some(source_spec) = &package.value.build.source {
-            match &source_spec {
-                pixi_spec::SourceLocationSpec::Path(path_spec) => {
-                    let resolved_path = path_spec.resolve(pixi.workspace_path()).unwrap();
-                    let expected_path = absolute_source_dir.canonicalize().unwrap();
-                    let resolved_canonical = resolved_path.canonicalize().unwrap();
+    if let Some(package) = &workspace.package
+        && let Some(source_spec) = &package.value.build.source
+    {
+        match &source_spec {
+            pixi_spec::SourceLocationSpec::Path(path_spec) => {
+                let resolved_path = path_spec.resolve(pixi.workspace_path()).unwrap();
+                let expected_path = absolute_source_dir.canonicalize().unwrap();
+                let resolved_canonical = resolved_path.canonicalize().unwrap();
 
-                    assert_eq!(resolved_canonical, expected_path);
-                    assert!(resolved_path.join("recipe.yaml").exists());
-                }
-                _ => panic!("Expected a path source spec"),
+                assert_eq!(resolved_canonical, expected_path);
+                assert!(resolved_path.join("recipe.yaml").exists());
             }
+            _ => panic!("Expected a path source spec"),
         }
     }
 }
@@ -216,7 +214,7 @@ preview = ["pixi-build"]
 async fn test_build_with_subdirectory_source_path() {
     setup_tracing();
 
-    let mut package_database = PackageDatabase::default();
+    let mut package_database = MockRepoData::default();
     package_database.add_package(Package::build("empty-backend", "0.1.0").finish());
 
     let channel_dir = TempDir::new().unwrap();
@@ -265,25 +263,25 @@ preview = ["pixi-build"]
 
     let workspace = pixi.workspace().unwrap();
 
-    if let Some(package) = &workspace.package {
-        if let Some(source_spec) = &package.value.build.source {
-            match &source_spec {
-                pixi_spec::SourceLocationSpec::Path(path_spec) => {
-                    // Test that the original relative path is preserved
-                    assert_eq!(path_spec.path.as_str(), "./subdir/source");
+    if let Some(package) = &workspace.package
+        && let Some(source_spec) = &package.value.build.source
+    {
+        match &source_spec {
+            pixi_spec::SourceLocationSpec::Path(path_spec) => {
+                // Test that the original relative path is preserved
+                assert_eq!(path_spec.path.as_str(), "./subdir/source");
 
-                    // Test that it resolves to the correct absolute location
-                    let resolved_path = path_spec.resolve(pixi.workspace_path()).unwrap();
-                    assert!(resolved_path.is_absolute());
-                    assert!(resolved_path.join("recipe.yaml").exists());
+                // Test that it resolves to the correct absolute location
+                let resolved_path = path_spec.resolve(pixi.workspace_path()).unwrap();
+                assert!(resolved_path.is_absolute());
+                assert!(resolved_path.join("recipe.yaml").exists());
 
-                    // Verify the resolved path matches our expectation
-                    let expected_path = subdir_source.canonicalize().unwrap();
-                    let resolved_canonical = resolved_path.canonicalize().unwrap();
-                    assert_eq!(resolved_canonical, expected_path);
-                }
-                _ => panic!("Expected a path source spec"),
+                // Verify the resolved path matches our expectation
+                let expected_path = subdir_source.canonicalize().unwrap();
+                let resolved_canonical = resolved_path.canonicalize().unwrap();
+                assert_eq!(resolved_canonical, expected_path);
             }
+            _ => panic!("Expected a path source spec"),
         }
     }
 }
@@ -341,6 +339,65 @@ my-package = {{ path = "./my-package" }}
     ));
 }
 
+/// Test that verifies the build command can accept a path to a recipe.yaml file
+/// via the --build-manifest argument
+#[tokio::test]
+async fn test_build_command_with_recipe_yaml_path() {
+    setup_tracing();
+
+    let pixi = PixiControl::new().unwrap();
+
+    // Create a separate directory with a recipe.yaml
+    let recipe_dir = pixi.workspace_path().join("my-recipe");
+    fs::create_dir_all(&recipe_dir).unwrap();
+
+    let recipe_content = r#"
+package:
+  name: test-package-from-recipe
+  version: 0.1.0
+
+build:
+  number: 0
+  noarch: generic
+
+about:
+  summary: Test package built from recipe.yaml
+"#;
+    let recipe_path = recipe_dir.join("recipe.yaml");
+    fs::write(&recipe_path, recipe_content).unwrap();
+
+    // Create a workspace manifest (pixi.toml) for workspace configuration
+    let manifest_content = format!(
+        r#"
+[workspace]
+channels = ["conda-forge"]
+platforms = ["{}"]
+preview = ["pixi-build"]
+"#,
+        Platform::current()
+    );
+
+    fs::write(pixi.manifest_path(), manifest_content).unwrap();
+
+    // Verify that the recipe.yaml file exists and is readable
+    assert!(
+        recipe_path.exists(),
+        "recipe.yaml should exist at the expected path"
+    );
+
+    assert!(
+        recipe_path.is_file(),
+        "recipe.yaml should be a file, not a directory"
+    );
+
+    // Verify the content can be read
+    let content = fs::read_to_string(&recipe_path).unwrap();
+    assert!(
+        content.contains("test-package-from-recipe"),
+        "recipe.yaml should contain the package name"
+    );
+}
+
 /// Test that verifies [package.build] source.path is resolved relative to the
 /// package manifest directory, not the workspace root.
 ///
