@@ -6,17 +6,14 @@ use tempfile::tempdir;
 use typed_path::Utf8TypedPath;
 
 use crate::common::pypi_index::{Database as PyPIDatabase, PyPIPackage};
-use crate::common::{
-    LockFileExt, PixiControl,
-    package_database::{Package, PackageDatabase},
-};
+use crate::common::{LockFileExt, PixiControl};
 use crate::setup_tracing;
+use pixi_test_utils::{MockRepoData, Package};
 
 /// This tests if we can resolve pyproject optional dependencies recursively
 /// before when running `pixi list -e all`, this would have not included numpy
 /// we are now explicitly testing that this works
 #[tokio::test]
-#[cfg_attr(not(feature = "online_tests"), ignore)]
 async fn pyproject_optional_dependencies_resolve_recursively() {
     setup_tracing();
 
@@ -30,7 +27,7 @@ async fn pyproject_optional_dependencies_resolve_recursively() {
     let platform = Platform::current();
     let platform_str = platform.to_string();
 
-    let mut package_db = PackageDatabase::default();
+    let mut package_db = MockRepoData::default();
     package_db.add_package(
         Package::build("python", "3.11.0")
             .with_subdir(platform)
@@ -60,6 +57,7 @@ test = ["recursive-optional-groups[np]", "pytest", {{include-group = "docs"}}]
 [tool.pixi.workspace]
 channels = ["{channel_url}"]
 platforms = ["{platform_str}"]
+conda-pypi-map = {{}}
 
 [tool.pixi.dependencies]
 python = "==3.11.0"
@@ -99,10 +97,20 @@ test = {{features = ["test"]}}
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_flat_links_based_index_returns_path() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     // Build a local flat (find-links) index with a single wheel: foo==1.0.0
     let index = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
@@ -113,13 +121,14 @@ async fn test_flat_links_based_index_returns_path() {
 
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-flat-find-links"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         foo = "*"
@@ -127,7 +136,8 @@ async fn test_flat_links_based_index_returns_path() {
         [pypi-options]
         find-links = [{{ path = "{find_links_path}"}}]
         "#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
         find_links_path = find_links_path,
     ));
     let lock_file = pixi.unwrap().update_lock_file().await.unwrap();
@@ -136,7 +146,7 @@ async fn test_flat_links_based_index_returns_path() {
     // Our wheel builder uses the tag py3-none-any by default.
     assert_eq!(
         lock_file
-            .get_pypi_package_url("default", Platform::current(), "foo")
+            .get_pypi_package_url("default", platform, "foo")
             .unwrap()
             .as_path()
             .unwrap(),
@@ -146,10 +156,20 @@ async fn test_flat_links_based_index_returns_path() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_file_based_index_returns_path() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     let simple = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
         .into_simple_index()
@@ -157,13 +177,14 @@ async fn test_file_based_index_returns_path() {
 
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-extra-index-url"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         foo = "*"
@@ -172,14 +193,15 @@ async fn test_file_based_index_returns_path() {
         extra-index-urls = [
             "{index_url}"
         ]"#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
         index_url = simple.index_url(),
     ));
     let lock_file = pixi.unwrap().update_lock_file().await.unwrap();
 
     assert_eq!(
         lock_file
-            .get_pypi_package_url("default", Platform::current(), "foo")
+            .get_pypi_package_url("default", platform, "foo")
             .unwrap()
             .as_path()
             .unwrap(),
@@ -190,10 +212,21 @@ async fn test_file_based_index_returns_path() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(not(feature = "online_tests"), ignore)]
 async fn test_index_strategy() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     let idx_a = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
         .into_simple_index()
@@ -209,13 +242,14 @@ async fn test_index_strategy() {
 
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-extra-index-url"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         foo = "*"
@@ -248,7 +282,8 @@ async fn test_index_strategy() {
         unsafe-first-match-constrained = ["unsafe-first-match-constrained"]
         unsafe-best-match = ["unsafe-best-match"]
         "#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
         idx_a = idx_a.index_url(),
         idx_b = idx_b.index_url(),
         idx_c = idx_c.index_url(),
@@ -257,38 +292,40 @@ async fn test_index_strategy() {
     let lock_file = pixi.unwrap().update_lock_file().await.unwrap();
 
     assert_eq!(
-        lock_file.get_pypi_package_version("default", Platform::current(), "foo"),
+        lock_file.get_pypi_package_version("default", platform, "foo"),
         Some("1.0.0".into())
     );
     assert_eq!(
-        lock_file.get_pypi_package_version(
-            "unsafe-first-match-unconstrained",
-            Platform::current(),
-            "foo"
-        ),
+        lock_file.get_pypi_package_version("unsafe-first-match-unconstrained", platform, "foo"),
         Some("1.0.0".into())
     );
 
     assert_eq!(
-        lock_file.get_pypi_package_version(
-            "unsafe-first-match-constrained",
-            Platform::current(),
-            "foo"
-        ),
+        lock_file.get_pypi_package_version("unsafe-first-match-constrained", platform, "foo"),
         Some("3.0.0".into())
     );
     assert_eq!(
-        lock_file.get_pypi_package_version("unsafe-best-match", Platform::current(), "foo"),
+        lock_file.get_pypi_package_version("unsafe-best-match", platform, "foo"),
         Some("3.0.0".into())
     );
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 /// This test checks if we can pin a package from a PyPI index, by explicitly specifying the index.
 async fn test_pinning_index() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     let idx = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
         .into_simple_index()
@@ -296,19 +333,21 @@ async fn test_pinning_index() {
 
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-pinning-index"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         foo = {{ version = "*", index = "{idx_url}" }}
 
         "#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
         idx_url = idx.index_url(),
     ));
 
@@ -316,7 +355,7 @@ async fn test_pinning_index() {
 
     assert_eq!(
         lock_file
-            .get_pypi_package_url("default", Platform::current(), "foo")
+            .get_pypi_package_url("default", platform, "foo")
             .unwrap()
             .as_path()
             .unwrap(),
@@ -327,7 +366,7 @@ async fn test_pinning_index() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(not(feature = "online_tests"), ignore)]
 /// This test checks if we can receive torch correctly from the whl/cu124 index.
 async fn pin_torch() {
     setup_tracing();
@@ -339,19 +378,37 @@ async fn pin_torch() {
         _ => format!("\"{platform}\", \"linux-64\""),
     };
 
+    // Create local conda channel with Python for all relevant platforms
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(Platform::Linux64)
+            .finish(),
+    );
+    if platform != Platform::Linux64 {
+        package_db.add_package(
+            Package::build("python", "3.12.0")
+                .with_subdir(platform)
+                .finish(),
+        );
+    }
+    let channel = package_db.into_channel().await.unwrap();
+
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-pinning-index"
         platforms = [{platforms}]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [target.linux-64.pypi-dependencies]
         torch = {{ version = "*", index = "https://download.pytorch.org/whl/cu124" }}
         "#,
+        channel_url = channel.url(),
     ));
 
     let lock_file = pixi.unwrap().update_lock_file().await.unwrap();
@@ -370,26 +427,47 @@ async fn pin_torch() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(not(feature = "online_tests"), ignore)]
 async fn test_allow_insecure_host() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
+    // Create local PyPI index with sh package
+    let pypi_index = PyPIDatabase::new()
+        .with(PyPIPackage::new("sh", "2.0.0"))
+        .into_simple_index()
+        .unwrap();
+
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-extra-index-url"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         sh = "*"
 
         [pypi-options]
+        index-url = "{pypi_index_url}"
         extra-index-urls = ["https://expired.badssl.com/"]"#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
+        pypi_index_url = pypi_index.index_url(),
     ))
     .unwrap();
     // will occur ssl error
@@ -414,24 +492,47 @@ async fn test_allow_insecure_host() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(not(feature = "online_tests"), ignore)]
 async fn test_tls_no_verify_with_pypi_dependencies() {
+    setup_tracing();
+
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
+    // Create local PyPI index with sh package
+    let pypi_index = PyPIDatabase::new()
+        .with(PyPIPackage::new("sh", "2.0.0"))
+        .into_simple_index()
+        .unwrap();
+
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-tls-test"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         sh = "*"
 
         [pypi-options]
+        index-url = "{pypi_index_url}"
         extra-index-urls = ["https://expired.badssl.com/"]"#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
+        pypi_index_url = pypi_index.index_url(),
     ))
     .unwrap();
 
@@ -475,24 +576,47 @@ async fn test_tls_no_verify_with_pypi_dependencies() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(not(feature = "online_tests"), ignore)]
 async fn test_tls_verify_still_fails_without_config() {
+    setup_tracing();
+
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
+    // Create local PyPI index with sh package
+    let pypi_index = PyPIDatabase::new()
+        .with(PyPIPackage::new("sh", "2.0.0"))
+        .into_simple_index()
+        .unwrap();
+
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-tls-verify-test"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         sh = "*"
 
         [pypi-options]
+        index-url = "{pypi_index_url}"
         extra-index-urls = ["https://expired.badssl.com/"]"#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
+        pypi_index_url = pypi_index.index_url(),
     ))
     .unwrap();
 
@@ -516,7 +640,10 @@ async fn test_tls_verify_still_fails_without_config() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(
+    any(not(feature = "online_tests"), not(feature = "slow_integration_tests")),
+    ignore
+)]
 async fn test_indexes_are_passed_when_solving_build_pypi_dependencies() {
     setup_tracing();
 
@@ -626,7 +753,10 @@ async fn test_indexes_are_passed_when_solving_build_pypi_dependencies() {
 /// even when the lower version appears first in `extra-index-urls`.
 /// This was an issue in: https://github.com/prefix-dev/pixi/issues/4588
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+#[cfg_attr(
+    any(not(feature = "online_tests"), not(feature = "slow_integration_tests")),
+    ignore
+)]
 async fn test_index_strategy_respected_for_build_dependencies() {
     setup_tracing();
 
@@ -689,7 +819,6 @@ async fn test_index_strategy_respected_for_build_dependencies() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_cross_platform_resolve_with_no_build() {
     setup_tracing();
 
@@ -700,6 +829,15 @@ async fn test_cross_platform_resolve_with_no_build() {
         Platform::OsxArm64
     };
 
+    // Create local conda channel with Python for the resolve platform
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(resolve_platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     // Use a local flat index for foo==1.0.0
     let flat = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
@@ -707,13 +845,14 @@ async fn test_cross_platform_resolve_with_no_build() {
         .expect("failed to create flat index");
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "pypi-extra-index-url"
         platforms = ["{platform}"]
-        channels = ["https://prefix.dev/conda-forge"]
+        channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
-        python = "~=3.12.0"
+        python = "==3.12.0"
 
         [pypi-dependencies]
         foo = "*"
@@ -722,6 +861,7 @@ async fn test_cross_platform_resolve_with_no_build() {
         no-build = true
         find-links = [{{ path = "{find_links}"}}]"#,
         platform = resolve_platform,
+        channel_url = channel.url(),
         find_links = flat.path().display().to_string().replace("\\", "/"),
     ));
     let lock_file = pixi.unwrap().update_lock_file().await.unwrap();
@@ -742,15 +882,13 @@ async fn test_cross_platform_resolve_with_no_build() {
 ///
 /// We expect there to be a help message that informs the user about the pinned package
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_pinned_help_message() {
     setup_tracing();
 
     // Construct a minimal local conda channel with python and pandas==1.0.0
-    use crate::common::package_database::{Package, PackageDatabase};
     use rattler_conda_types::Platform;
 
-    let mut conda_db = PackageDatabase::default();
+    let mut conda_db = MockRepoData::default();
     // Python runtime
     conda_db.add_package(
         Package::build("python", "3.12.0")
@@ -778,6 +916,7 @@ async fn test_pinned_help_message() {
         r#"
         [workspace]
         channels = ["{channel}"]
+        conda-pypi-map = {{}}
         name = "local-pinned-help"
         platforms = ["{platform}"]
         version = "0.1.0"
@@ -808,10 +947,20 @@ async fn test_pinned_help_message() {
 }
 
 #[tokio::test]
-#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_uv_index_correctly_parsed() {
     setup_tracing();
 
+    let platform = Platform::current();
+
+    // Create local conda channel with Python
+    let mut package_db = MockRepoData::default();
+    package_db.add_package(
+        Package::build("python", "3.12.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+
     // Provide a local simple index containing `foo` used in build-system requires.
     let simple = PyPIDatabase::new()
         .with(PyPIPackage::new("foo", "1.0.0"))
@@ -846,13 +995,15 @@ async fn test_uv_index_correctly_parsed() {
         module-root = ""
 
         [tool.pixi.workspace]
-        channels = ["conda-forge"]
+        channels = ["{channel_url}"]
         platforms = ["{platform}"]
+        conda-pypi-map = {{}} # Disable mapping
 
         [tool.pixi.pypi-dependencies]
         simple = {{ path = "." }}
         "#,
-        platform = Platform::current(),
+        platform = platform,
+        channel_url = channel.url(),
         index_url = simple.index_url(),
     ))
     .unwrap();
@@ -889,7 +1040,7 @@ async fn test_prerelease_mode_allow() {
 
     let platform = Platform::current();
 
-    let mut package_db = PackageDatabase::default();
+    let mut package_db = MockRepoData::default();
     package_db.add_package(
         Package::build("python", "3.12.0")
             .with_subdir(platform)
@@ -901,10 +1052,11 @@ async fn test_prerelease_mode_allow() {
     // With prerelease-mode = "allow", the resolver should pick the pre-release 2.0.0a1
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "prerelease-test"
         platforms = ["{platform}"]
         channels = ["{channel_url}"]
+        conda-pypi-map = {{}} # Disable mapping
 
         [dependencies]
         python = "==3.12.0"
@@ -950,7 +1102,7 @@ async fn test_prerelease_mode_disallow() {
 
     let platform = Platform::current();
 
-    let mut package_db = PackageDatabase::default();
+    let mut package_db = MockRepoData::default();
     package_db.add_package(
         Package::build("python", "3.12.0")
             .with_subdir(platform)
@@ -962,10 +1114,11 @@ async fn test_prerelease_mode_disallow() {
     // With prerelease-mode = "disallow", the resolver should pick the stable 1.0.0
     let pixi = PixiControl::from_manifest(&format!(
         r#"
-        [project]
+        [workspace]
         name = "prerelease-test"
         platforms = ["{platform}"]
         channels = ["{channel_url}"]
+        conda-pypi-map = {{}}
 
         [dependencies]
         python = "==3.12.0"
