@@ -2,7 +2,7 @@ use std::collections::HashMap;
 
 use indexmap::{IndexMap, IndexSet};
 use miette::IntoDiagnostic;
-use pixi_core::workspace::{PypiDeps, UpdateDeps, WorkspaceMut};
+use pixi_core::workspace::{Environment, PypiDeps, UpdateDeps, WorkspaceMut};
 use pixi_core::{Workspace, environment::LockFileUsage};
 use pixi_manifest::{
     EnvironmentName, Feature, FeatureName, PrioritizedChannel, SpecType, TargetSelector, Task,
@@ -10,11 +10,13 @@ use pixi_manifest::{
 };
 use pixi_pypi_spec::{PixiPypiSpec, PypiPackageName};
 use pixi_spec::PixiSpec;
-use rattler_conda_types::{Channel, MatchSpec, PackageName, Platform, RepoDataRecord};
+use rattler_conda_types::{
+    Channel, MatchSpec, NamedChannelOrUrl, PackageName, Platform, RepoDataRecord,
+};
 
 use crate::interface::Interface;
 use crate::workspace::add::GitOptions;
-use crate::workspace::{DependencyOptions, InitOptions, ReinstallOptions};
+use crate::workspace::{ChannelOptions, DependencyOptions, InitOptions, ReinstallOptions};
 
 pub struct DefaultContext<I: Interface> {
     _interface: I,
@@ -81,6 +83,106 @@ impl<I: Interface> WorkspaceContext<I> {
         crate::workspace::workspace::name::set(&self.interface, self.workspace_mut()?, name).await
     }
 
+    pub async fn description(&self) -> Option<String> {
+        crate::workspace::workspace::description::get(&self.workspace).await
+    }
+
+    pub async fn set_description(&self, description: &str) -> miette::Result<()> {
+        crate::workspace::workspace::description::set(
+            &self.interface,
+            self.workspace_mut()?,
+            description,
+        )
+        .await
+    }
+
+    pub async fn list_channel(&self) -> HashMap<EnvironmentName, Vec<NamedChannelOrUrl>> {
+        crate::workspace::workspace::channel::list(&self.workspace).await
+    }
+
+    pub async fn add_channel(&self, options: ChannelOptions) -> miette::Result<()> {
+        crate::workspace::workspace::channel::add(&self.interface, self.workspace_mut()?, options)
+            .await
+    }
+
+    pub async fn remove_channel(&self, options: ChannelOptions) -> miette::Result<()> {
+        crate::workspace::workspace::channel::remove(
+            &self.interface,
+            self.workspace_mut()?,
+            options,
+        )
+        .await
+    }
+
+    pub async fn list_platforms(&self) -> HashMap<EnvironmentName, Vec<Platform>> {
+        crate::workspace::workspace::platform::list(&self.workspace).await
+    }
+
+    pub async fn add_platforms(
+        &self,
+        platform: Vec<Platform>,
+        no_install: bool,
+        feature: Option<String>,
+    ) -> miette::Result<()> {
+        crate::workspace::workspace::platform::add(
+            &self.interface,
+            self.workspace_mut()?,
+            platform,
+            no_install,
+            feature,
+        )
+        .await
+    }
+
+    pub async fn remove_platforms(
+        &self,
+        platform: Vec<Platform>,
+        no_install: bool,
+        feature: Option<String>,
+    ) -> miette::Result<()> {
+        crate::workspace::workspace::platform::remove(
+            &self.interface,
+            self.workspace_mut()?,
+            platform,
+            no_install,
+            feature,
+        )
+        .await
+    }
+
+    pub async fn list_environments(&self) -> Vec<Environment<'_>> {
+        crate::workspace::workspace::environment::list(&self.workspace).await
+    }
+
+    pub async fn add_environment(
+        &self,
+        name: EnvironmentName,
+        features: Option<Vec<String>>,
+        solve_group: Option<String>,
+        no_default_feature: bool,
+        force: bool,
+    ) -> miette::Result<()> {
+        crate::workspace::workspace::environment::add(
+            &self.interface,
+            self.workspace_mut()?,
+            name,
+            features,
+            solve_group,
+            no_default_feature,
+            force,
+        )
+        .await
+    }
+
+    pub async fn remove_environment(&self, name: &str) -> miette::Result<()> {
+        crate::workspace::workspace::environment::remove(
+            &self.interface,
+            self.workspace_mut()?,
+            name,
+        )
+        .await
+    }
+
     pub async fn list_features(&self) -> IndexMap<FeatureName, Feature> {
         crate::workspace::workspace::feature::list_features(&self.workspace).await
     }
@@ -136,6 +238,18 @@ impl<I: Interface> WorkspaceContext<I> {
             .await
     }
 
+    pub async fn remove_feature(
+        &self,
+        feature: &FeatureName,
+    ) -> miette::Result<Vec<EnvironmentName>> {
+        crate::workspace::workspace::feature::remove_feature(
+            &self.interface,
+            self.workspace_mut()?,
+            feature,
+        )
+        .await
+    }
+
     pub async fn add_conda_deps(
         &self,
         specs: IndexMap<PackageName, MatchSpec>,
