@@ -1,12 +1,15 @@
 pub mod workspace;
 
 mod context;
-pub use context::WorkspaceContext;
+pub use context::{DefaultContext, WorkspaceContext};
 
 mod interface;
 pub use interface::Interface;
 
 // Reexport for pixi_api consumers
+pub use pep508_rs as pep508;
 pub use pixi_core as core;
 pub use pixi_manifest as manifest;
+pub use pixi_pypi_spec as pypi_spec;
+pub use pixi_spec as spec;
 pub use rattler_conda_types;
