@@ -1,5 +1,6 @@
 use rattler_conda_types::NamedChannelOrUrl;
 use serde::{Deserialize, Serialize};
+use std::collections::HashMap;
 use std::{cmp::PartialEq, path::PathBuf};
 
 #[derive(Debug, Serialize, Deserialize)]
@@ -21,6 +22,9 @@ pub struct InitOptions {
 
     /// Source Control Management used for this workspace.
     pub scm: Option<GitAttributes>,
+
+    /// The conda-pypi-mapping
+    pub conda_pypi_mapping: Option<HashMap<NamedChannelOrUrl, String>>,
 }
 
 #[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
