@@ -1,4 +1,6 @@
 use clap::Parser;
+use miette::IntoDiagnostic;
+use tokio::fs as tokio_fs;
 
 use pixi_global::EnvironmentName;
 
@@ -86,6 +88,18 @@ async fn revert_environment_after_error(
         let _ = project_to_revert_to
             .sync_environment(env_name, None)
             .await?;
+    } else {
+        // clean up if directory exists for the failed new environment
+        let env_dir_path = project_to_revert_to.env_root_path().join(env_name.as_str());
+        if env_dir_path.exists() {
+            tokio_fs::remove_dir_all(&env_dir_path)
+                .await
+                .into_diagnostic()?;
+            tracing::debug!(
+                "Cleaned up failed environment directory: {}",
+                env_dir_path.display()
+            );
+        }
     }
     Ok(())
 }
