@@ -1,5 +1,3 @@
-use std::fmt::Write;
-
 use clap::Parser;
 use fancy_display::FancyDisplay;
 use itertools::Itertools;
@@ -9,6 +7,7 @@ use pixi_core::{
     environment::{InstallFilter, get_update_lock_file_and_prefixes},
     lock_file::{LockFileDerivedData, PackageFilterNames, ReinstallPackages, UpdateMode},
 };
+use std::fmt::Write;
 
 use crate::cli_config::WorkspaceConfig;
 
@@ -132,7 +131,7 @@ pub async fn execute(args: Args) -> miette::Result<()> {
             "The {} environment has been installed",
             environment.name().fancy_display(),
         )
-        .unwrap();
+        .expect("failed to write into message buffer");
 
         if skip_opts {
             let platform = environment.best_platform();
@@ -147,7 +146,8 @@ pub async fn execute(args: Args) -> miette::Result<()> {
 
             // When only is set, also print the number of packages that will be installed
             if args.only.as_ref().is_some_and(|v| !v.is_empty()) {
-                write!(&mut message, ", including {num_retained} packages").unwrap();
+                write!(&mut message, ", including {num_retained} packages")
+                    .expect("failed to write into message buffer");
             }
 
             // Create set of unmatched packages, that matches the skip filter
@@ -175,7 +175,7 @@ pub async fn execute(args: Args) -> miette::Result<()> {
                         " excluding '{}'",
                         skipped_packages_vec.join("', '")
                     )
-                    .unwrap();
+                    .expect("failed to write into message buffer");
                 } else if num_skipped > 0 {
                     let num_matched = matched.len();
                     if num_matched > 0 {
@@ -185,28 +185,29 @@ pub async fn execute(args: Args) -> miette::Result<()> {
                             matched.into_iter().join("', '"),
                             num_skipped
                         )
-                        .unwrap()
+                        .expect("failed to write into message buffer")
                     } else {
-                        write!(&mut message, " excluding {num_skipped} other packages").unwrap()
+                        write!(&mut message, " excluding {num_skipped} other packages")
+                            .expect("failed to write into message buffer")
                     }
                 } else {
                     write!(
                         &mut message,
                         " no packages were skipped (check if cli args were correct)"
                     )
-                    .unwrap();
+                    .expect("failed to write into message buffer");
                 }
             }
         }
     } else {
+        let env = environments
+            .iter()
+            .format_with(", ", |e, f| f(&e.name().fancy_display()));
         write!(
             &mut message,
-            "The following environments have been installed: {}",
-            environments
-                .iter()
-                .format_with(", ", |e, f| f(&e.name().fancy_display())),
+            "The following environments have been installed: {env}",
         )
-        .unwrap();
+        .expect("failed to write into message buffer");
     }
 
     if let Ok(Some(path)) = workspace.config().detached_environments().path() {
@@ -215,7 +216,7 @@ pub async fn execute(args: Args) -> miette::Result<()> {
             " in '{}'",
             console::style(path.display()).bold()
         )
-        .unwrap()
+        .expect("failed to write into message buffer");
     }
 
     eprintln!("{message}.");
