@@ -1,7 +1,7 @@
 //! See [`BackendSourceBuildSpec`]
 
 use std::{
-    collections::{BTreeMap, BTreeSet},
+    collections::{BTreeMap, BTreeSet, BinaryHeap},
     fmt::Display,
     path::PathBuf,
 };
@@ -18,7 +18,7 @@ use pixi_build_types::{
         CondaBuildV1PrefixPackage, CondaBuildV1Result, CondaBuildV1RunExports,
     },
 };
-use pixi_record::PinnedSourceSpec;
+use pixi_glob::GlobSet;
 use pixi_spec::{BinarySpec, PixiSpec, SpecConversionError};
 use rattler_conda_types::{
     ChannelConfig, ChannelUrl, MatchSpec, PackageName, Platform, RepoDataRecord,
@@ -46,8 +46,9 @@ pub struct BackendSourceBuildSpec {
     /// The package that we are building.
     pub package: PackageIdentifier,
 
-    /// The source location of the package that we are building.
-    pub source: PinnedSourceSpec,
+    /// The directory where the source code is located on disk.
+    #[serde(skip)]
+    pub source_dir: PathBuf,
 
     /// The method to use for building the source package.
     pub method: BackendSourceBuildMethod,
@@ -116,7 +117,11 @@ pub struct BackendBuiltSource {
 
     /// The globs that were used as input to the build. Use these for
     /// re-verifying the build.
-    pub input_globs: BTreeSet<String>,
+    pub input_globs: BinaryHeap<String>,
+
+    /// The actual files that matched the globs at build time. This allows
+    /// detecting file deletions and additions.
+    pub input_files: BTreeSet<PathBuf>,
 }
 
 impl BackendSourceBuildSpec {
@@ -130,6 +135,7 @@ impl BackendSourceBuildSpec {
                     self.backend,
                     self.package,
                     params,
+                    self.source_dir,
                     self.work_directory,
                     self.channels,
                     self.channel_config,
@@ -140,10 +146,12 @@ impl BackendSourceBuildSpec {
         }
     }
 
+    #[allow(clippy::too_many_arguments)]
     async fn build_v1(
         backend: Backend,
         record: PackageIdentifier,
         params: BackendSourceBuildV1Method,
+        source_dir: PathBuf,
         work_directory: PathBuf,
         channels: Vec<ChannelUrl>,
         channel_config: ChannelConfig,
@@ -284,8 +292,25 @@ impl BackendSourceBuildSpec {
             ));
         };
 
+        // Compute the files that match the input globs.
+        let glob_set = GlobSet::create(built_package.input_globs.iter().map(String::as_str));
+        let input_files = glob_set
+            .collect_matching(&source_dir)
+            .map_err(BackendSourceBuildError::GlobSet)
+            .map_err(CommandDispatcherError::Failed)?
+            .into_iter()
+            .filter_map(|entry| {
+                entry
+                    .into_path()
+                    .strip_prefix(&source_dir)
+                    .ok()
+                    .map(|p| p.to_path_buf())
+            })
+            .collect();
+
         Ok(BackendBuiltSource {
-            input_globs: built_package.input_globs,
+            input_globs: built_package.input_globs.into_iter().collect(),
+            input_files,
             output_file: built_package.output_file,
         })
     }
@@ -379,6 +404,9 @@ pub enum BackendSourceBuildError {
 
     #[error(transparent)]
     UnexpectedPackage(UnexpectedPackageError),
+
+    #[error(transparent)]
+    GlobSet(#[from] pixi_glob::GlobSetError),
 }
 
 /// An error that can occur when the build backend did not return the expected
