@@ -1,4 +1,4 @@
-use crate::toml::ExternalWorkspaceProperties;
+use crate::toml::{ExternalWorkspaceProperties, PackageDefaults};
 use crate::toml::{FromTomlStr, TomlManifest};
 use itertools::Itertools;
 use pixi_test_utils::format_parse_error;
@@ -9,7 +9,11 @@ use pixi_test_utils::format_parse_error;
 pub(crate) fn expect_parse_failure(pixi_toml: &str) -> String {
     let parse_error = TomlManifest::from_toml_str(pixi_toml)
         .and_then(|manifest| {
-            manifest.into_workspace_manifest(ExternalWorkspaceProperties::default(), None)
+            manifest.into_workspace_manifest(
+                ExternalWorkspaceProperties::default(),
+                PackageDefaults::default(),
+                None,
+            )
         })
         .expect_err("parsing should fail");
 
@@ -21,7 +25,11 @@ pub(crate) fn expect_parse_failure(pixi_toml: &str) -> String {
 #[must_use]
 pub(crate) fn expect_parse_warnings(pixi_toml: &str) -> String {
     match <TomlManifest as FromTomlStr>::from_toml_str(pixi_toml).and_then(|manifest| {
-        manifest.into_workspace_manifest(ExternalWorkspaceProperties::default(), None)
+        manifest.into_workspace_manifest(
+            ExternalWorkspaceProperties::default(),
+            PackageDefaults::default(),
+            None,
+        )
     }) {
         Ok((_, _, warnings)) => warnings
             .into_iter()
