@@ -42,6 +42,9 @@ pub struct Workspace {
     /// Channel priority for the whole project
     pub channel_priority: Option<ChannelPriority>,
 
+    /// Solve strategy for the whole project.
+    pub solve_strategy: Option<SolveStrategy>,
+
     /// The platforms this project supports
     pub platforms: IndexSet<Platform>,
 
@@ -138,3 +141,50 @@ impl From<rattler_solve::ChannelPriority> for ChannelPriority {
         }
     }
 }
+
+#[derive(
+    Debug,
+    Copy,
+    Clone,
+    Default,
+    Eq,
+    PartialEq,
+    strum::Display,
+    strum::VariantNames,
+    strum::EnumString,
+    Deserialize,
+)]
+#[serde(rename_all = "kebab-case")]
+#[strum(serialize_all = "kebab-case")]
+pub enum SolveStrategy {
+    #[default]
+    Highest,
+    Lowest,
+    LowestDirect,
+}
+
+impl<'de> toml_span::Deserialize<'de> for SolveStrategy {
+    fn deserialize(value: &mut Value<'de>) -> Result<Self, DeserError> {
+        TomlEnum::deserialize(value).map(TomlEnum::into_inner)
+    }
+}
+
+impl From<SolveStrategy> for rattler_solve::SolveStrategy {
+    fn from(value: SolveStrategy) -> Self {
+        match value {
+            SolveStrategy::Highest => rattler_solve::SolveStrategy::Highest,
+            SolveStrategy::Lowest => rattler_solve::SolveStrategy::LowestVersion,
+            SolveStrategy::LowestDirect => rattler_solve::SolveStrategy::LowestVersionDirect,
+        }
+    }
+}
+
+impl From<rattler_solve::SolveStrategy> for SolveStrategy {
+    fn from(value: rattler_solve::SolveStrategy) -> Self {
+        match value {
+            rattler_solve::SolveStrategy::Highest => Self::Highest,
+            rattler_solve::SolveStrategy::LowestVersion => Self::Lowest,
+            rattler_solve::SolveStrategy::LowestVersionDirect => Self::LowestDirect,
+        }
+    }
+}
